@@ -42,6 +42,10 @@ def daemon_thread(fn: Callable) -> Callable[..., Thread]:
 
     return _wrap
 
+
+def function_thread(fn: Callable, daemon: bool, *args, **kwargs):
+    return Thread(target=fn, args=args, kwargs=kwargs, daemon=daemon)
+
 '''
  @daemon_thread
     def thread_func():
